window.Gleam.initSearch([{"doc":"crabbucket_redis","title":"crabbucket_redis","content":"# crabbucket_redis\n\n[![Package Version](https://img.shields.io/hexpm/v/crabbucket_redis)](https://hex.pm/packages/crabbucket_redis)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/crabbucket_redis/)\n\n```sh\ngleam add crabbucket_redis\n```\n\nThe intention of this library is to provide a function,\n`remaining_tokens_for_key(bucket, key, default_token_count)`,\nwhich performs an atomic write in Redis and whose return value is used in\ndetermining whether a certain action should be taken / allowed.\nIt is chiefly intended for use with web backends.\n\n## Disclaimer\n\nThis library is currently in pre-release while its design and reliability are\nunder review.\n\n## Usage\n\n[The Wisp API example](./examples/wisp_api_limit_example/src/wisp_api_limit_example.gleam)\nshowcases how to use this library with Wisp middleware to apply rate limiting to an API.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/crabbucket_redis&gt;.\n\n## Development\n\nUnit tests run against a Valkey instance, spun up via `podman-compose`\n\n```sh\nmake test\n```\n","url":"index.html"},{"doc":"crabbucket/redis","title":"RedisTokenBucket","content":"pub type RedisTokenBucket {\n  RedisTokenBucket(\n    redis_connection: Subject(Message),\n    window_duration_milliseconds: Int,\n  )\n}\n `window_duration_milliseconds` describes the length of the time window\n valid for a number of tokens.\n For instance, a value of 1,000 with a default token count of 100 would mean\n an action could occur 100 times per second.\nRedisTokenBucket(\n  redis_connection: Subject(Message),\n  window_duration_milliseconds: Int,\n)\n\n\nSynonyms:\ncrabbucket/redis.RedisTokenBucket\ncrabbucket/redis RedisTokenBucket","url":"crabbucket/redis.html#RedisTokenBucket"},{"doc":"crabbucket/redis","title":"RemainingTokenCountFailure","content":"pub type RemainingTokenCountFailure {\n  MustWaitUntil(next_reset_timestamp: Int)\n  RedisError(error: Error)\n}\n\nMustWaitUntil(next_reset_timestamp: Int)\n\n\nRedisError(error: Error)\n\n\nSynonyms:\ncrabbucket/redis.RemainingTokenCountFailure\ncrabbucket/redis RemainingTokenCountFailure","url":"crabbucket/redis.html#RemainingTokenCountFailure"},{"doc":"crabbucket/redis","title":"RemainingTokenCountSuccess","content":"pub type RemainingTokenCountSuccess {\n  HasRemainingTokens(\n    remaining_tokens: Int,\n    next_reset_timestamp: Int,\n  )\n}\n\nHasRemainingTokens(\n  remaining_tokens: Int,\n  next_reset_timestamp: Int,\n)\n\n\nSynonyms:\ncrabbucket/redis.RemainingTokenCountSuccess\ncrabbucket/redis RemainingTokenCountSuccess","url":"crabbucket/redis.html#RemainingTokenCountSuccess"},{"doc":"crabbucket/redis","title":"clear_key","content":"pub fn clear_key(\n  bucket: RedisTokenBucket,\n  key: String,\n) -&gt; Result(Bool, Error)\n Returns True if record was deleted, False if record didn&#39;t exist\nSynonyms:\ncrabbucket/redis.clear_key\ncrabbucket/redis clear_key","url":"crabbucket/redis.html#clear_key"},{"doc":"crabbucket/redis","title":"remaining_tokens_for_key","content":"pub fn remaining_tokens_for_key(\n  bucket: RedisTokenBucket,\n  key: String,\n  default_token_count: Int,\n) -&gt; Result(\n  RemainingTokenCountSuccess,\n  RemainingTokenCountFailure,\n)\n Takes an arbitrary string key, inserting a record if non-existing.\n \n Suggestion: you may wish to format you string key such that it indicates\n usage, purpose, value type, and value.\n For instance, if you&#39;re limiting a specific endpoint for a given user,\n the key might look something like:\n `limit:some_endpoint_name:user:12345`\n \n Return should be either `HasRemainingTokens(remaining_tokens: Int)`,\n which indicates that an action may proceed and contains how many more times\n the action may occur with the current window,\n or it may be `MustWaitFor(milliseconds: Int)`,\n which indicates that no tokens remain for this keep and how many\n milliseconds remain until the end of the current window.\nSynonyms:\ncrabbucket/redis.remaining_tokens_for_key\ncrabbucket/redis remaining_tokens_for_key","url":"crabbucket/redis.html#remaining_tokens_for_key"},{"doc":"crabbucket/redis","title":"crabbucket/redis","content":"","url":"crabbucket/redis.html"}]);